@@ -4,7 +4,7 @@ use POE::Component::Pluggable::Pipeline;
 use POE::Component::Pluggable::Constants qw(:ALL);
 use vars qw($VERSION);
 
-$VERSION='0.01';
+$VERSION='0.02';
 
 sub _pluggable_init {
   my $self = shift;
@@ -33,10 +33,14 @@ sub _pluggable_process {
   my $return = PLUGIN_EAT_NONE;
 
   if ( $self->can($sub) ) {
-    eval { $self->$sub( $self, @args ) };
+    eval { $ret = $self->$sub( $self, @args ) };
     warn "$@" if $@;
   }
 
+  return $return if $ret == PLUGIN_EAT_PLUGIN;
+  $return = PLUGIN_EAT_ALL if $ret == PLUGIN_EAT_CLIENT;
+  return PLUGIN_EAT_ALL if $ret == PLUGIN_EAT_ALL;
+
   for my $plugin (@{ $pipeline->{PIPELINE} }) {
     next if $self eq $plugin;
     next
@@ -351,6 +355,10 @@ and inserting _pluggable_process() wherever you dispatch events from.
 Users of your component can then load plugins using the plugin methods provided to handle events
 generated by the component.
 
+You may also use plugin style handlers within your component as _pluggable_process() will attempt to
+process any events with local method calls first. The return value of these handlers has the same 
+significance as the return value of 'normal' plugin handlers.
+
 =head1 PRIVATE METHODS
 
 Subclassing POE::Component::Pluggable gives your object the following 'private' methods:
